pub struct ContextAccumulatorSnapshot {
pub context_id: &'static str,
pub state: Matrix3,
pub state_hash: u64,
pub update_count: u64,
pub last_update_unix_ms: u64,
}Expand description
Value-bearing snapshot used to prove inactive contexts remain byte-equal.
Fields
context_id: &'static strstate: Matrix3state_hash: u64update_count: u64last_update_unix_ms: u64Trait Implementations
Sourceimpl Clone for ContextAccumulatorSnapshot
impl Clone for ContextAccumulatorSnapshot
Sourcefn clone(&self) -> ContextAccumulatorSnapshot
fn clone(&self) -> ContextAccumulatorSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ContextAccumulatorSnapshot
Sourceimpl Debug for ContextAccumulatorSnapshot
impl Debug for ContextAccumulatorSnapshot
Sourceimpl PartialEq for ContextAccumulatorSnapshot
impl PartialEq for ContextAccumulatorSnapshot
Sourcefn eq(&self, other: &ContextAccumulatorSnapshot) -> bool
fn eq(&self, other: &ContextAccumulatorSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ContextAccumulatorSnapshot