pub struct CertificateInputs {
pub tick_id: u64,
pub prior_a_t: Matrix3,
pub reference_r_t: Matrix3,
pub realized_a_next: Matrix3,
pub alpha_t: f64,
pub delta_alpha_t: f64,
pub epsilon_q: f64,
pub policy_margin: f64,
}Expand description
Inputs to compute the runtime certificate end to end from the update matrices.
Fields
tick_id: u64prior_a_t: Matrix3reference_r_t: Matrix3realized_a_next: Matrix3alpha_t: f64delta_alpha_t: f64epsilon_q: f64policy_margin: f64Trait Implementations
Sourceimpl Clone for CertificateInputs
impl Clone for CertificateInputs
Sourcefn clone(&self) -> CertificateInputs
fn clone(&self) -> CertificateInputs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CertificateInputs
Sourceimpl Debug for CertificateInputs
impl Debug for CertificateInputs
Sourceimpl PartialEq for CertificateInputs
impl PartialEq for CertificateInputs
Sourcefn eq(&self, other: &CertificateInputs) -> bool
fn eq(&self, other: &CertificateInputs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CertificateInputs