NarrationDepth

Enum NarrationDepth 

pub enum NarrationDepth {
    None,
    Minimal,
    Brief,
    Full,
    Deep,
}
Narration depth levels gated by output permeability.

Determines how much reflection the robot performs based on the current permeability. Lower permeability means less narration overhead.

Variants



None

permeability < 0.2: No reflection.



Minimal

permeability 0.2–0.4: Factual observations only.



Brief

permeability 0.4–0.6: Contextual awareness.



Full

permeability 0.6–0.8: Personality-colored narration.



Deep

permeability > 0.8: Phenomenological reflection.

Implementations

Source

impl NarrationDepth

pub fn from_permeability(p: f32) -> Self

Map a permeability scalar to a narration depth level.